# Slot: default_range


default slot range to be used if range element is omitted from a slot definition

URI: [http://w3id.org/biolink/biolinkml/meta/default_range](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [Definition](Definition.md)
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
